@@ -1,7 +1,7 @@
 package Empyrion;
 our $AUTHORITY = 'cpan:GETTY';
-# ABSTRACT: TODO
-$Empyrion::VERSION = '0.002';
+# ABSTRACT: Modules around Empyrion - Galactical Survial
+$Empyrion::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -13,11 +13,11 @@ __END__
 
 =head1 NAME
 
-Empyrion - TODO
+Empyrion - Modules around Empyrion - Galactical Survial
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
